### 0.10.8 {small}`2024-08-09`

```{rubric} Features
```
* adds `tl.score_genes` {pr}`235` {smaller}`S Dicks`
* adds `tl.score_genes_cell_cycle` {pr}`235` {smaller}`S Dicks`
* adds `get.X_to_GPU` and `get.X_to_CPU` {pr}`235` {smaller}`S Dicks`
* adds `dcg.run_aucell` {pr}`236` {smaller}`S Dicks`


```{rubric} Misc
```
* updates tests to run on rapids-24.08 {pr}`241` {smaller}`S Dicks`
* updates docker to on rapids-24.08 {pr}`241` {smaller}`S Dicks`
* updates docker to run with cuda-12 {pr}`241` {smaller}`S Dicks`
